isolated_malformed_request_outcome

Function isolated_malformed_request_outcome 

pub fn isolated_malformed_request_outcome() -> Outcome
A row Suotar refused as a malformed request even in a batch of its own: resending the same request is refused the same way, so it needs a human.