released_unsent_split_half

Function released_unsent_split_half 

pub fn released_unsent_split_half() -> UnaskedMove
An import row a split still held unsent when a shutdown or an error stopped the split.