pub fn request_level_code(
kind: RegistryErrorKind,
) -> CreditRegistrationErrorCodeExpand description
The ledger error code for a request the study registry rejected, or never answered, as a whole.
pub fn request_level_code(
kind: RegistryErrorKind,
) -> CreditRegistrationErrorCodeThe ledger error code for a request the study registry rejected, or never answered, as a whole.