submit_error_outcome

Function submit_error_outcome 

pub fn submit_error_outcome(
    endpoint: SuotarEndpoint,
    code: CreditRegistrationErrorCode,
    facts: &RowFacts,
) -> Outcome
A per-item error on the calls leading towards a submission. Only import creates attainments, so anything uncertain there is verify-only, while the same code on resolve-enrolments retries.