pub struct UnaskedMove {
pub outcome: Outcome,
pub message: Option<String>,
}Expand description
A move a phase makes on a claimed row without an answer to decide from: the outcome, and the timeline line that explains it.
Fields
outcome: Outcomemessage: Option<String>Implementations
Sourceimpl UnaskedMove
impl UnaskedMove
pub(super) fn new(outcome: Outcome, message: impl Into<String>) -> Self
pub(super) fn silent(outcome: Outcome) -> Self
Sourcepub fn transition(
&self,
expected_from_state: Option<CreditRegistrationState>,
now: DateTime<Utc>,
) -> Transition
pub fn transition( &self, expected_from_state: Option<CreditRegistrationState>, now: DateTime<Utc>, ) -> Transition
The ledger write, guarded and timed as Outcome::transition.