pub fn released_unsent_split_half() -> UnaskedMoveExpand description
An import row a split still held unsent when a shutdown or an error stopped the split.
pub fn released_unsent_split_half() -> UnaskedMoveAn import row a split still held unsent when a shutdown or an error stopped the split.