retry_or_expire

Function retry_or_expire 

fn retry_or_expire(
    code: CreditRegistrationErrorCode,
    endpoint: SuotarEndpoint,
    facts: &RowFacts,
) -> Outcome
Retryable until the row has been failing for a week, and then a support case rather than an endless one.