fn retry_or_expire(
code: CreditRegistrationErrorCode,
endpoint: SuotarEndpoint,
facts: &RowFacts,
) -> OutcomeExpand description
Retryable until the row has been failing for a week, and then a support case rather than an endless one.
fn retry_or_expire(
code: CreditRegistrationErrorCode,
endpoint: SuotarEndpoint,
facts: &RowFacts,
) -> OutcomeRetryable until the row has been failing for a week, and then a support case rather than an endless one.