pub fn submitting() -> UnaskedMoveExpand description
Committed before the import request leaves: a row found in submitting after a restart has an
unknown outcome and is never sent again.
pub fn submitting() -> UnaskedMoveCommitted before the import request leaves: a row found in submitting after a restart has an
unknown outcome and is never sent again.